@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.40';
+$Test::BDD::Cucumber::Executor::VERSION = '0.41';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 DESCRIPTION
 
@@ -16,7 +16,7 @@ Definitions, and reporting on progress through the passed-in harness.
 =cut
 
 use Moose;
-use Storable qw(dclone);
+use Clone qw(clone);
 use List::Util qw/first/;
 use List::MoreUtils qw/pairwise/;
 use Module::Runtime qw/use_module/;
@@ -50,7 +50,7 @@ reference are:
 -----
 You can safetly ignore the global $Test::Builder::Test. In almost all cases, the
 simple fix is the move the line that says `use Test::BDD::Cucumber::Executor`
-above all other `use Test::*` lines. You can also supress this check by setting:
+above all other `use Test::*` lines. You can also suppress this check by setting:
 
   TEST_BDD_CUCUMBER_NO_TB_WRAP_TEST=1
 END
@@ -281,7 +281,7 @@ sub execute_scenario {
                     # Data portion
                     columns => $step->columns || [],
                     data => ref( $step->data )
-                    ? dclone( $step->data )
+                    ? clone( $step->data )
                     : $step->data || '',
 
                     # Step-specific info
@@ -408,7 +408,7 @@ sub dispatch {
     $tb_return->{'builder'}->failure_output( \$output );
     $tb_return->{'builder'}->todo_output( \$output );
 
-    # Make a minumum pass
+    # Make a minimum pass
     $tb_return->{'builder'}
         ->ok( 1, "Starting to execute step: " . $context->text );
 
@@ -446,7 +446,7 @@ sub dispatch {
         };
 
         # Take a copy of this. Turns out actually matching against it
-        # directly causes all sorts of weird-ass eisenbugs which mst has
+        # directly causes all sorts of weird-ass heisenbugs which mst has
         # promised to investigate.
         my $text = $context->text;
 
