@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.40';
+$Test::BDD::Cucumber::Parser::VERSION = '0.41';
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 DESCRIPTION
 
@@ -135,7 +135,7 @@ sub _extract_feature_name {
             push( @feature_tags, @tags );
 
         } else {
-            die parse_error_from_line( "Malformed feature line", $line );
+            die parse_error_from_line( 'Malformed feature line (expecting: /^(?:' . $self->{langdef}->{feature} . '): (.+)/', $line );
         }
     }
 
@@ -172,7 +172,7 @@ sub _extract_scenarios {
 
         my $langdef = $self->{langdef};
         if ( $line->content =~
-m/^((?:$langdef->{background})|(?:$langdef->{scenario}))(?: Outline)?: ?(.+)?/
+m/^((?:$langdef->{background})|(?:$langdef->{scenario})|(?:$langdef->{scenario_outline})): ?(.+)?/
           )
         {
             my ( $type, $name ) = ( $1, $2 );
@@ -197,6 +197,13 @@ m/^((?:$langdef->{background})|(?:$langdef->{scenario}))(?: Outline)?: ?(.+)?/
             # Attempt to populate it
             @lines = $self->_extract_steps( $feature, $scenario, @lines );
 
+            # Catch Scenario outlines without examples
+            if ( $type =~ m/^($langdef->{scenario_outline})/
+                   && ! @{$scenario->data} ) {
+                die parse_error_from_line(
+                "Outline scenario expects 'Examples:' section", $line)
+            }
+
             if ( $type =~ m/^($langdef->{background})/ ) {
                 $feature->background($scenario);
             } else {
